/*********************************************************************

    formats/trd_dsk.h

    TRD disk images

*********************************************************************/

#ifndef TRD_DSK_H
#define TRD_DSK_H

#include "flopimg.h"

/**************************************************************************/

LEGACY_FLOPPY_OPTIONS_EXTERN(trd);

#endif /* TRD_DSK_H */
